@@ -34,31 +34,30 @@ if (ngroup==2) {
            names(prob)<-ny
          }
       else prob[2]<-0
-      prob.group<-a$fitted.values
-          yest<-factor(yest,levels=ny)
+      prob.group[,1]<-1-a[[1]]$fitted.values
+      prob.group[,2]<-a[[1]]$fitted.values 
+      yest<-factor(yest,levels=ny)
  #devolver a mayores y estimada!
    }
-else {
-   prob.group<-array(NA,dim=c(n,ngroup))
-   colnames(prob.group)<-ny
+else {    
    for (i in 1:ngroup) {
               newy<-ifelse(y==ny[i],0,1)
               newdata$df[[response]]<-newy                
               a[[i]]<-fregre.gsam(formula,data=newdata,family=family,weights=weights,
               basis.x=basis.x,basis.b=basis.b,CV=CV,...)
-              prob.group[,i]<-a[[i]]$fitted.values
+              prob.group[,i]<-1-a[[i]]$fitted.values
             }
-   yest<-ny[apply(prob.group,1,which.min)]#no ser which.max
+   yest<-ny[apply(prob.group,1,which.max)]
    yest<-factor(yest,levels=ny)
-   tab<-table(yest,y)
+   tab<-table(yest,y) 
+   prob.group<-prob.group/apply(prob.group,1,sum)   
    for (i in 1:ngroup) {     prob[i]=tab[i,i]/sum(tab[,i])     }
    names(prob)<-ny
 }
+colnames(prob.group)<-ny
 max.prob=sum(diag(tab))/sum(tab)  
 output<-list(formula=formula,data=data,group=y,group.est=yest,
 prob.classification=prob,prob.group=prob.group,C=C,m=m,max.prob=max.prob,fit=a)
 class(output)="classif"
 return(output)
 }
-
-
