@@ -200,7 +200,7 @@ fdata2pc<-function (fdataobj,  ncomp = 2,norm = TRUE,lambda=0,P=c(0,0,1),...)
     C <- match.call()
     if (!is.fdata(fdataobj))
         stop("No fdata class")
-    nas1 <- apply(fdataobj$data, 1, count.na)
+    nas1 <- is.na.fdata(fdataobj)
     if (any(nas1))
         stop("fdataobj contain ", sum(nas1), " curves with some NA value \n")
     X <- fdataobj[["data"]]
@@ -331,7 +331,7 @@ else {
     S<-Minverse(S)
     H<-Z%*%S%*%t(Z)
     e<-object.lm$residuals
-    df = max(traza(H),pc$df[lenl]+1)
+    df = max(fdata.trace(H),pc$df[lenl]+1)
     rdf<-n-df
     sr2 <- sum(e^2)/rdf
     Vp<-sr2*S 
@@ -385,7 +385,7 @@ else {
       normx<-sqrt(sum(abs((t(x)%*%x)^2)))
       normp<-sqrt(sum(abs(P2^2)))
       normip<-sqrt(sum(abs(diag(nc)+P2)^2))
-      pii <-traza(P2)
+      pii <-fdata.trace(P2)
       lambda0<-(-2*pii+sqrt(4*pii^2-4*(nc-normx^2)*normp^2))/(2*normp^2)
       #  lambda1<-normx/normp
       lambda<-seq(0,sqrt(lambda0),len=10)
@@ -491,7 +491,7 @@ fregre.pc.cv=function (fdataobj, y, kmax=8,lambda=0,P=c(1,0,0),criteria = "SIC",
         normx<-sqrt(sum(abs((t(x)%*%x)^2)))
         normp<-sqrt(sum(abs(P2^2)))
         normip<-sqrt(sum(abs(diag(np)+P2)^2))
-        pii <-traza(P2)
+        pii <-fdata.trace(P2)
         lambda0<-(-2*pii+sqrt(4*pii^2-4*(np-normx^2)*normp^2))/(2*normp^2)
         #  lambda1<-normx/normp
         #print(lambda0)
@@ -743,7 +743,7 @@ fregre.pc=function (fdataobj, y, l =NULL,lambda=0,P=c(1,0,0),weights=rep(1,len=n
     coefs<-Cinv%*%y
     yp<-drop(scores%*%coefs)
     H<-scores%*%Cinv
-    df<-traza(H)
+    df<-fdata.trace(H)
     coefs<-drop(coefs)
     names(coefs)<-c("Intercept",cnames)
     beta.est<-coefs[-1]*pc$rotation[l]
@@ -798,7 +798,7 @@ fregre.pc=function (fdataobj, y, l =NULL,lambda=0,P=c(1,0,0),weights=rep(1,len=n
     S<-Minverse(S) 
     H<-Z%*%S%*%t(Z)
     e<-object.lm$residuals
-    df<-traza(df)#n- object.lm$df
+    df<-fdata.trace(df)#n- object.lm$df
     sr2 <- sum(e^2)/(n - df)
     Vp<-sr2*S 
     r2 <- 1 - sum(e^2)/sum(ycen^2)
